"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _enzymeToJson = require("enzyme-to-json");

var _mock_api = require("../mock_api");

var _mock_data = _interopRequireDefault(require("../mock_api/mock_data"));

var _ = _interopRequireDefault(require("../"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var MOCK_API_DELAY = 100;
var searchFunction = (0, _mock_api.getSearchFunction)(MOCK_API_DELAY);

var getDelayedPromise = function getDelayedPromise() {
  var delay = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  return new Promise(function (r) {
    return setTimeout(r, delay);
  });
};

describe('components/SearchPicker', function () {
  var component;
  var renderedData;
  var onItemSelectedStub;
  describe('default case', function () {
    beforeEach(function () {
      onItemSelectedStub = jest.fn();
      component = (0, _enzyme.mount)(_react["default"].createElement(_["default"], {
        onItemSelected: onItemSelectedStub,
        searchFunction: searchFunction,
        supportedTypes: ['feature']
      }, function (data) {
        renderedData = data;
        return _react["default"].createElement("div", null, data.renderInput(), _react["default"].createElement("p", null, "A list of entities"));
      }));
    });
    it('should render component same as snapshot', function () {
      expect((0, _enzymeToJson.mountToJson)(component)).toMatchSnapshot();
    });
    it('should pass a default list of items on creation', function () {
      return getDelayedPromise().then(function () {
        component.find('input').simulate('click');
      }).then(function () {
        return getDelayedPromise(MOCK_API_DELAY);
      }).then(function () {
        component.update();
        expect(renderedData.availableEntities).toHaveLength(5);
      });
    });
    it('should update the list when a search term is entered', function () {
      return getDelayedPromise().then(function () {
        component.find('input').simulate('mouseenter');
        component.find('input').simulate('click');
        component.find('input').simulate('input', {
          target: {
            value: '123'
          }
        });
      }) // Account for our mock API delay and the debounce delay
      .then(function () {
        return getDelayedPromise(MOCK_API_DELAY + 10);
      }).then(function () {
        component.update();
        expect(renderedData.availableEntities).toHaveLength(1);
        expect(renderedData.availableEntities[0].name).toContain('My feature 123');
      });
    });
    it('should pass isLoading, searchQuery, and availableEntities correctly', function () {
      expect(renderedData.isLoading).toBe(true);
      return getDelayedPromise(MOCK_API_DELAY).then(function () {
        expect(renderedData.searchQuery).toBe('');
        expect(renderedData.isLoading).toBe(false);
        component.find('input').simulate('mouseenter');
        component.find('input').simulate('click');
        component.find('input').simulate('input', {
          target: {
            value: '123'
          }
        });
      }) // Wait for debounce
      .then(function () {
        return getDelayedPromise(10);
      }).then(function () {
        expect(renderedData.searchQuery).toBe('123');
        expect(renderedData.isLoading).toBe(true);
      }) // Account for our mock API delay and the debounce delay
      .then(function () {
        return getDelayedPromise(MOCK_API_DELAY + 10);
      }).then(function () {
        component.update();
        expect(renderedData.isLoading).toBe(false);
        expect(renderedData.availableEntities).toEqual([_mock_data["default"][0]]);
      });
    });
    it('should wait to show results until all queries are completed', function () {
      expect(renderedData.isLoading).toBe(true);
      return getDelayedPromise(MOCK_API_DELAY).then(function () {
        expect(renderedData.resultsText).toEqual({
          summary: 'Recently created features'
        });
        component.find('input').simulate('mouseenter');
        component.find('input').simulate('click');
        component.find('input').simulate('input', {
          target: {
            value: '123'
          }
        });
      }) // Wait for debounce
      .then(function () {
        return getDelayedPromise(10);
      }).then(function () {
        expect(renderedData.searchQuery).toBe('123');
        expect(renderedData.isLoading).toBe(true);
        component.update();
        expect(renderedData.resultsText).toEqual({
          summary: 'Searching for "features" matching "123"'
        });
        component.find('input').simulate('mouseenter');
        component.find('input').simulate('click');
        component.find('input').simulate('input', {
          target: {
            value: '202'
          }
        });
      }).then(function () {
        return getDelayedPromise(MOCK_API_DELAY);
      }).then(function () {
        component.update();
        expect(renderedData.resultsText).toEqual({
          summary: 'Searching for "features" matching "202"'
        });
      }) // Account for our mock API delay and the debounce delay
      .then(function () {
        return getDelayedPromise(MOCK_API_DELAY + 10);
      }).then(function () {
        component.update();
        expect(renderedData.isLoading).toBe(false);
        expect(renderedData.resultsText).toEqual({
          summary: 'Found 1 features matching "202"'
        });
      });
    });
  });
});